@@ -1,20 +1,21 @@
 package Filename::Video;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-10-20'; # DATE
-our $DIST = 'Filename-Video'; # DIST
-our $VERSION = '0.004'; # VERSION
-
 use 5.010001;
 use strict;
 use warnings;
 
 use Exporter qw(import);
+
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2024-01-12'; # DATE
+our $DIST = 'Filename-Video'; # DIST
+our $VERSION = '0.005'; # VERSION
+
 our @EXPORT_OK = qw(check_video_filename);
 
 our $STR_RE = "movie|mpeg|webm|3gp|asf|asx|avi|axv|dif|fli|flv|lsf|lsx|mkv|mng|mov|mp4|mpe|mpg|mpv|mxu|ogv|wmv|wmx|wvx|dl|dv|gl|qt|ts|wm"; # STR_RE
 
-our $RE = qr(\.(?:$STR_RE)\z)i;
+our $RE = qr(\A(.+)\.($STR_RE)\z)i;
 
 our %SPEC;
 
@@ -31,12 +32,6 @@ _
             req => 1,
             pos => 0,
         },
-        # XXX recurse?
-        #ci => {
-        #    summary => 'Whether to match case-insensitively',
-        #    schema  => 'bool',
-        #    default => 1,
-        #},
     },
     result_naked => 1,
     result => {
@@ -59,18 +54,18 @@ _
         },
         {
             args => {filename => 'foo.webm'},
-            naked_result => {},
+            naked_result => {filename_without_suffix=>"foo", suffix=>"webm"},
         },
         {
             args => {filename => 'foo.MP4'},
-            naked_result => {},
+            naked_result => {filename_without_suffix=>"foo", suffix=>"MP4"},
         },
     ],
 };
 sub check_video_filename {
     my %args = @_;
 
-    $args{filename} =~ $RE ? {} : 0;
+    $args{filename} =~ $RE ? {filename_without_suffix=>$1, suffix=>$2} : 0;
 }
 
 1;
@@ -88,7 +83,7 @@ Filename::Video - Check whether filename indicates being a video file
 
 =head1 VERSION
 
-This document describes version 0.004 of Filename::Video (from Perl distribution Filename-Video), released on 2020-10-20.
+This document describes version 0.005 of Filename::Video (from Perl distribution Filename-Video), released on 2024-01-12.
 
 =head1 SYNOPSIS
 
@@ -127,11 +122,11 @@ Examples:
 
 =item * Example #3:
 
- check_video_filename(filename => "foo.webm"); # -> {}
+ check_video_filename(filename => "foo.webm"); # -> { filename_without_suffix => "foo", suffix => "webm" }
 
 =item * Example #4:
 
- check_video_filename(filename => "foo.MP4"); # -> {}
+ check_video_filename(filename => "foo.MP4"); # -> { filename_without_suffix => "foo", suffix => "MP4" }
 
 =back
 
@@ -143,6 +138,8 @@ Arguments ('*' denotes required arguments):
 
 =item * B<filename>* => I<filename>
 
+(No description)
+
 
 =back
 
@@ -160,14 +157,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/Filename-V
 
 Source repository is at L<https://github.com/perlancar/perl-Filename-Video>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Filename-Video>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<Filename::Audio>
@@ -182,11 +171,37 @@ L<Filename::Media>
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020, 2017 by perlancar@cpan.org.
+This software is copyright (c) 2024, 2020, 2017 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Filename-Video>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
